.. RED-I documentation master file, created by sphinx-quickstart
.. http://sphinx-doc.org/tutorial.html
.. http://sphinx-doc.org/markup/toctree.html#toctree-directive

Welcome to RED-I's documentation!
=================================

The project documentation is split into two sections

* :ref:`user_docs`
* :ref:`developer_docs`

.. _user_docs:

User Documentation
~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2

   about
   redi_configuration
   redi_usage
   add_new_redcap_project
   clinical_data_specification
   describing_a_redcap_form_to_redi
   mapping_clinical_components_to_loinc_codes


.. _developer_docs:

Developer Documentation
~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 2
   
   test_sample_project_using_vagrant
   code_review_checklist
   setup_travis_ci
   integration_testing
   api/modules

..  Indices and tables
..  ==================
..  
..  * :ref:`genindex`
..  * :ref:`modindex`
..  * :ref:`search`

